<template>
  <div class="dialogBox">
    <div
      class="journalBox"
      v-if="info.cmsItemType === 'journal' || info.cmsItemType === 'books'"
    >
      <div :title="info.name" class="title">{{ info.name }}</div>
      <div class="subtitle">
        <div class="source">{{ info.source }}</div>
        <div class="journalInformation">{{ info.IssueNumber }}</div>
      </div>
      <div class="contentBox">
        <span>{{ info.author }}</span>
        <span style="margin-left: 20px"> {{ info.authorsUnits }}</span>
        <span></span>
      </div>
      <div class="abstract">
        摘要：
        <span v-html="info.abstract"></span>
      </div>
      <div class="keyword">
        关键词： <span>{{ info.keyWords }}</span>
      </div>
    </div>
    <div class="imageBox" v-if="info.cmsItemType === 'image'">
      <div style="width: 350px; height: 200px; position: relative">
        <img
          class="autoImg"
          src="@/assets/images/chronology/photoTest.png"
          alt=""
        />
      </div>
      <div
        style="
          display: flex;
          width: 100%;
          justify-content: space-between;
          margin-top: 50px;
        "
      >
        <div class="ARROWS">←</div>
        <div class="ARROWS">→</div>
      </div>
    </div>
    <div class="videoBox" v-if="info.cmsItemType === 'video'">
      <video width="370" height="200" controls :src="info.fileLink"></video>

      <div>
        <div class="subtitle">
          <div class="source">{{ info.source }}</div>
          <div class="journalInformation">2005 3月 第40卷 第4期</div>
        </div>
        <div class="contentBox" style="text-align: left">
          <div class="contentBox" style="text-align: left">
            <div class="audioContent" v-html="info.abstract"></div>
          </div>
        </div>
      </div>
    </div>
    <div class="audioBox" v-if="info.cmsItemType === 'audio'">
      <div style="text-align: center">
        <audio
          style="width: 90%"
          :src="info.fileLink"
          controls
        ></audio>
      </div>
      <div>
        <div class="subtitle">
          <div class="source">{{ info.source }}</div>
          <div class="journalInformation">2005 3月 第40卷 第4期</div>
        </div>
        <div class="contentBox" style="text-align: left">
          <div class="audioContent" v-html="info.abstract"></div>
        </div>
      </div>
    </div>

    <div class="btnBox">
      <div @click="toDetail" class="detailBtn">查看详情</div>
    </div>
  </div>
</template>

<script>
export default {
  name: "floatingWindow",
  props: {
    info: {
      type: Object,
      default: () => {},
    },
  },

  data() {
    return {};
  },
  mounted() {
    console.log(this.info);
  },
  methods: {
    toDetail() {
      this.$router.push({ name: "details", query: { id: this.info.id } });
    },
  },
};
</script>

<style scoped>
.dialogBox {
  width: 524px;
  height: 100%;
  background-color: #fdf8f0;
  position: relative;
  padding: 15px;
  z-index: 20;
  box-sizing: border-box;
}
.title {
  font-size: 16px;
  line-height: 22px;
  font-weight: 600;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  margin-top: 10px;
}

.subtitle {
  display: flex;
  justify-content: space-between;
}
.subtitle {
  margin-top: 20px;
}
.abstract {
  margin-top: 10px;
  white-space: pre-line;
  line-height: 18px;
}
.keyword {
  margin-top: 10px;
  white-space: pre-line;
  line-height: 18px;
}
.contentBox {
  margin-top: 10px;
  line-height: 18px;
  white-space: pre-line;
}
.imageBox {
  min-height: 300px;
  padding: 10px;
}

.videoBox {
  min-height: 240;
  text-align: center;
}
.videoTitle {
  background: #ffffff;
  box-sizing: border-box;
  border: 1px solid #dcdcdc;
  box-shadow: 0px 0px 10px 0px;
  display: flex;
  justify-content: center;
  align-items: center;
  border-radius: 5px;
  padding: 10px;
  width: 100%;
  height: 100%;
}
.autoImg {
  width: 100%;
  height: 100%;
  object-fit: cover;
}
.ARROWS {
  font-size: 24px;
  line-height: 40px;
  width: 40px;
  height: 40px;
  border-radius: 50%;
  border: 1px solid #8f7a5a;
  display: flex;
  justify-content: center;
  align-items: center;
  cursor: pointer;
  font-weight: 700;
  color: #8f7a5a;
}
.source {
  max-width: 300px;
  overflow: hidden;
  white-space: normal;
}
.btnBox {
  text-align: center;
  margin-top: 20px;
  display: flex;
  justify-content: center;
}
.detailBtn {
  width: 100px;
  height: 30px;
  border-radius: 30px;
  color: #8f7a5a;
  line-height: 30px;
  cursor: pointer;
  border: 1px solid #8f7a5a;
}
.audioContent {
  white-space: pre-line;
  line-height: 18px;
  margin-top: 10px;
  max-height: 100px;
  overflow-y: auto;
  margin-top: 20px;
}
video {
      border-radius: 10px;
      border: 1px solid #dcdcdc;
      box-shadow: 0px 0px 10px 0px rgba(0, 0, 0, 0.1);
    }
</style>
